function maxima = findmaxima(x)

%========================================================================
% Non-photorealistic Rendering, Version 1.0
% Author: Yamini Nimmagadda
%
% This is an implementation of the non-photorealistic rendering algorithm
% for reducing image sizes by removing fine details. Please refer to
% to the following paper:
%
% Yamini Nimmagadda, Yung-Hsiang Lu, Edward J. Delp, and David S. Ebert,
% "Non-photorealistic Rendering for Energy Conservation in Portable
% Devices", Electronic Imaging (ISTSPIE), 2008.
%
% Kindly report any suggestions or corrections to ynimmaga@purdue.edu
%
%----------------------------------------------------------------------
%
% Input : x: input row matrix in which the local maxima are to be computed
% Output: maxima: local maxima of x

% Unwrap to vector
x = x(:);

% Identify whether signal is rising or falling
upordown = sign(diff(x));

% Find points where signal is rising before, falling after
maxflags = [upordown(1)<0; diff(upordown)<0; upordown(end)>0];
maxima   = find(maxflags);

