function Inormalized = normalize(I, I_segment, mag, level)

%========================================================================
% Non-photorealistic Rendering, Version 1.0
% Author: Yamini Nimmagadda
%
% This is an implementation of the non-photorealistic rendering algorithm
% for reducing image sizes by removing fine details. Please refer to
% to the following paper:
%
% Yamini Nimmagadda, Yung-Hsiang Lu, Edward J. Delp, and David S. Ebert,
% "Non-photorealistic Rendering for Energy Conservation in Portable
% Devices", Electronic Imaging (ISTSPIE), 2008.
%
% Kindly report any suggestions or corrections to ynimmaga@purdue.edu
%
%----------------------------------------------------------------------
%
% Input : (1) I: input image to be rendered
%         (2) I_segment: segmented image
%         (3) mag: frequency gradient threshold
%         (4) level: intensity gradient threshold
%
% Output: Inormalized: normalized output image
mag = mag + 10 * level;


[m,n] = size(I); % Find the dimensions of the image
k = m * n; % Total number of pixels in an image

Il = zeros(m, n);
cov = zeros(m, n);

% Find all the pixels with the same label and classify them into the same segment
for i = 1 : k - 1              
    a = find(I_segment == i);
    s = 0;
    
    % Computing mean of each segment
    if ((length(a) ~= 0) & (cov(a(1)) ~= 1))
        for j = 1 : length(a)
            s = s + double(I(a(j)));
        end
        mean1 = s / length(a);

         if (i == 1)
             meanprev = mean1;
         end
        
        % If the pixel intensity is greater than mean value, then lower it to the mean value

        if (((abs(meanprev-mean1)) < abs(mag))) 
            m = min(mean1, meanprev);
            mean1 = m; 
            meanprev = m;
        end
        
        for j = 1 : length(a)
            Il(a(j)) = i;
            cov(a(j)) = 1;
            if (I(a(j)) > mean1)
                I(a(j)) = mean1;
            end
            if (I(a(j)) < mean1)
                I(a(j)) = mean1;
            end
        end
         meanprev = mean1;
    end
end

% The mormalized image is returned.
Inormalized = I;

