%========================================================================
% Non-photorealistic Rendering, Version 1.0
% Author: Yamini Nimmagadda
%
% This is an implementation of the non-photorealistic rendering algorithm
% for reducing image sizes by removing fine details. Please refer to
% to the following paper:
%
% Yamini Nimmagadda, Yung-Hsiang Lu, Edward J. Delp, and David S. Ebert,
% "Non-photorealistic Rendering for Energy Conservation in Portable
% Devices", Electronic Imaging (ISTSPIE), 2008.
%
% Kindly report any suggestions or corrections to ynimmaga@purdue.edu
%
%----------------------------------------------------------------------

clear all;
close all;

numfile = input('Enter the number of images for processing'); % Number of images for rendering
imstart = input('Enter the starting image number'); % Starting image number

jpgfile = dir('*.jpg'); % jpgfile stores all the JPEG files in the current directory
fId1 = fopen('nprlog', 'a'); % nprlog stores the input file names, output file names and sizes of all the files rendered.


for fileindex = imstart : numfile + imstart - 1
   fileindex
   fprintf(fId1, '\t %d: current time %d\n\n', fileindex, cputime());  % Print file number and current time in nprlog file
   inName = jpgfile(fileindex).name;                                   % Input file names
   outName = strcat('npr', inName);                                    % output file names are obtained by appending 'npr' to the inpur file names
   message = sprintf('%s -> %s', inName, outName)                      % print input file name and output file name in command window
   nprprocess(inName, outName);                                        % Rendering images
   outlist = dir(outName);                                             % list the output images 
   fprintf(fId1, '%s -> %s ', inName, outName);                        % print input file name and output file name in nprlog file
   fprintf(fId1, '\t%d %d %f\n', jpgfile(fileindex).bytes, outlist(1).bytes, outlist(1).bytes / jpgfile(fileindex).bytes); % print sizes  
end
fclose(fId1);

