function superimposed = superimpose(S1,S2)
    
%========================================================================
% Non-photorealistic Rendering, Version 1.0
% Author: Yamini Nimmagadda
%
% This is an implementation of the non-photorealistic rendering algorithm
% for reducing image sizes by removing fine details. Please refer to
% to the following paper:
%
% Yamini Nimmagadda, Yung-Hsiang Lu, Edward J. Delp, and David S. Ebert,
% "Non-photorealistic Rendering for Energy Conservation in Portable
% Devices", Electronic Imaging (ISTSPIE), 2008.
%
% Kindly report any suggestions or corrections to ynimmaga@purdue.edu
%
%----------------------------------------------------------------------
%
% Input : S1: input edge image 1
%         S2: input edge image 2
%
% Output: superimposed: the superimposed edge image
%        

% the superimposed image contains edges from both the edge images 
 
R = S1;
[row, col] = size(S1);
for i = 1 : row
    for j = 1 : col
        if (S1(i, j) == 0)
            R(i, j) = S2(i, j);
        elseif (S1(i, j) == 1)
            R(i, j) = S1(i, j);
        end
    end
end

superimposed = R;
