function [th, mag] = thresh(I)

%========================================================================
% Non-photorealistic Rendering, Version 1.0
% Author: Yamini Nimmagadda
%
% This is an implementation of the non-photorealistic rendering algorithm
% for reducing image sizes by removing fine details. Please refer to
% to the following paper:
%
% Yamini Nimmagadda, Yung-Hsiang Lu, Edward J. Delp, and David S. Ebert,
% "Non-photorealistic Rendering for Energy Conservation in Portable
% Devices", Electronic Imaging (ISTSPIE), 2008.
%
% Kindly report any suggestions or corrections to ynimmaga@purdue.edu
%
%----------------------------------------------------------------------
%
% Input : I: the matrix containing intensity values of a gray scaled image
%
% Output: (1) th : The intensity gradient threshold of the gray scaled 
%         image measured from the intensity histogram
%         (2) mag : The frequency threshold of the gray scaled image



% find the histogram of the image I
rhist = imhist(I);
[row, col] = size(rhist); % size of the histogram
a = findmaxima(rhist); % determine peaks of the histogram

% The array 't' is used to compute the minimum intensity difference
% It is initialized to all zeroes
for i = 1 : row
    t(i) = 0;
end
    
for i = 1 : length(a)
    t(a(i)) = rhist(a(i));
end

% Computing the minimum intensity and frequency thresholds from histogram   
for i = 2 : length(a)
    difm(i) = t(a(i)) - t(a(i - 1));
    dif(i) = a(i) - a(i - 1);
end
    
mag = min(abs(difm));  % mag is the minimum diffence between local maxima   
th = min(dif); % t is the maximum difference between adjacent maxima
